=======
History
=======

0.3.0 (2022-02-11)
------------------
* Add SHMI variant of Charlson Comorbidity Score. Based on SHMI Specification Version 1.35 2020-09-24 (https://files.digital.nhs.uk/B8/F8D021/SHMI%20specification%20v1.35.pdf)

0.2.1 (2021-01-02)
------------------

* Rewritten HFRS calculator that is 5x faster than previous version.

0.2.0 (2021-12-31)
------------------

* Add function for calculating Hospital Frailty Risk Score (https://www.thelancet.com/journals/lancet/article/PIIS0140-6736(18)30668-8/)

0.1.0 (2021-12-20)
------------------

* First release.
